MethodChannelAndroidXStorage class

An implementation of AndroidXStoragePlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAlarmsDirectory() → Future<String?>
Returns the alarms directory.
override
getDCIMDirectory() → Future<String?>
Returns the DCIM directory.
override
getDocumentsDirectory() → Future<String?>
Returns the documents directory.
override
getDownloadsDirectory() → Future<String?>
Returns the downloads directory.
override
getExternalStorageDirectory() → Future<String?>
Returns the external storage directory.
override
getMoviesDirectory() → Future<String?>
Returns the movies directory.
override
getMusicDirectory() → Future<String?>
Returns the music directory.
override
getNotificationsDirectory() → Future<String?>
Returns the notifications directory.
override
getPicturesDirectory() → Future<String?>
Returns the pictures directory.
override
getPlatformVersion() → Future<int?>
Returns the platform version.
override
getPodcastsDirectory() → Future<String?>
Returns the podcasts directory.
override
getRingtonesDirectory() → Future<String?>
Returns the ringtones directory.
override
getSDCardStorageDirectory() → Future<String?>
Returns the SD card storage directory.
override
getUSBStorageDirectories() → Future<List<String?>>
Returns the USB storage directories.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited